SUBROUTINE BOUND(IDX,NDATE)
!
!            BOUND is a modified version of a
!            boundary condition routine written by
!            E. A. Martinsen DNMI .
!
!***PURPOSE BOUND relaxes the solution in the FRS-zone
!           towards a specified FRS-zone solution.
!
!***DESCRIPTION
!
!           BOUND uses the FRS-bondary condition to specify
!           the solution in specified boundary zones.
!
!   ON ENTRY
!
!     IDX    Integer.
!            If IDX = 1 on entry, the water elevation , and the
!               depth averaged velocities UA and VA are
!               updated in the FRS-zone.
!            If IDX = 3 on entry, the 3-D horisontal velocities are
!               updated in the FRS-zone. 
!            If IDX = 4 on entry, the S and T fields are updated.
!            If IDX = 6 on entry, the Q2 and Q2L fields are updated.
!
!***ROUTINES CALLED RELAX
!***END PROLOGUE BOUND
!
!   Global variables
!
  USE MOD_BOUND
  IMPLICIT NONE
  INTEGER IDX,NDATE(5)
!
  INTEGER I,J,K
  REAL SDUM(IM,JM,KB)
!
!
  IF (IDX.EQ.3) THEN
!
!   Update the 3-D horizontal velocities at the boundaries.
!
     CALL RELAX(ALPHA,UFRS,UTFRS,U,2,KB-1)
     CALL RELAX(ALPHA,VFRS,VTFRS,V,3,KB-1)
!
!
!  Neumann on U-normal.
!
!     DO J = 13,14
!     DO K = 1,KB-1
!       U(1,J,K) = U(3,J,K)
!       U(2,J,K) = U(3,J,K)
!       V(1,J,K) = 0.
!       V(2,J,K) = 0.
!     END DO
!     END DO
!     DO I = 15,18
!     DO K = 1,KB-1
!       V(I,1,K) = V(I,3,K)
!       V(I,1,K) = V(I,3,K)
!       U(I,1,K) = 0.
!       U(I,2,K) = 0.
!     END DO
!     END DO
!
!
     DO K = 1,KB-1
        DO J = 1,JM
           DO I = 1,IM
              U(I,J,K)=U(I,J,K)*DUM(I,J)
              V(I,J,K)=V(I,J,K)*DVM(I,J)
           END DO
        END DO
     END DO
!
  ELSEIF (IDX.EQ.4) THEN
     SDUM = 0.
!
!   Update the 3-D horizontal velocities at the boundaries.
!
     CALL RELAX(ALPHA,SFRS,SDUM,S,1,KB-1)
     CALL RELAX(ALPHA,TFRS,SDUM,T,1,KB-1)
!
!   If RIVLOG is .TRUE., you may want to apply the below
!   Neumann-condition for S and T and comment away the above calls to RELAX.
!
!     DO J = 13,14
!     DO K = 1,KB-1
!       S(1,J,K) = S(3,J,K)
!       T(1,J,K) = T(3,J,K)
!       S(2,J,K) = S(3,J,K)
!       T(2,J,K) = T(3,J,K)
!     END DO
!     END DO
!     DO I = 15,18
!     DO K = 1,KB-1
!       S(I,1,K) = S(I,3,K)
!       T(I,1,K) = T(I,3,K)
!       S(I,2,K) = S(I,3,K)
!       T(I,2,K) = T(I,3,K)
!     END DO
!     END DO
!
!
!
     DO K = 1,KB-1
        DO J = 1,JM
           DO I = 1,IM
              S(I,J,K)=S(I,J,K)*FSM(I,J)
              T(I,J,K)=T(I,J,K)*FSM(I,J)
           END DO
        END DO
     END DO
  ELSEIF (IDX.EQ.6) THEN
     SDUM = 0.
!
!   Update Q2 and Q2L at the open boundaries.
!
     CALL RELAX(ALPHA,Q2FRS,SDUM,Q2,1,KB-1)
     CALL RELAX(ALPHA,Q2LFRS,SDUM,Q2L,1,KB-1)
!
     DO K = 1,KB-1
        DO J = 1,JM
           DO I = 1,IM
              Q2(I,J,K)=Q2(I,J,K)*FSM(I,J)
              Q2L(I,J,K)=Q2L(I,J,K)*FSM(I,J)
           END DO
        END DO
     END DO
  ENDIF
!
!***END BOUND
!
RETURN
END SUBROUTINE BOUND
