SUBROUTINE FIELDINIT
USE MOD_MAIN
IMPLICIT NONE
!
!   Local variables
!
REAL R1,R2,RR3,R4,R5,R6
!
REAL SMAX,SMINW,DELTAZS,ZS,S1Z,DEP,DELTAS
INTEGER IS
!
DATA R1,R2,RR3,R4,R5,R6/28.152,7.35E-2,4.69E-3,8.02E-1,2.0E-3,35.0/
!
!  Initialize ETA, ETAP, U, V, W, WR, S, T and D.
ETA = 0.
U = 0.
V = 0.
UADV = 0.0
VADV = 0.0
W = 0.
WR = 0.
S = 35.
T = 10.
!
!   Zero ETA in land points.
!
DO J = 1,JM
  DO I = 1,IM
    ETA(I,J) = ETA(I,J)*FSM(I,J)
  END DO
END DO
!
! If TIDE, set the water level throughout the fjord system
!
IF (TIDE) THEN
  ISTEP = 0
  IS = 0
  CALL TIDEFRS(IS)
  ETA = ETATFRS(2,13)
ENDIF
!
ETAP = ETA
!
!  Define the Salinity profile using a TANH function.
!
SMAX = 34.
SMINW = 27.
DELTAZS = 3.
ZS = -8.
DO I = 1,IM
  DO J = 1,JM
    IF (FSM(I,J).NE.0.) THEN
      DO K = 1,KB-1
        DEP = ZZ(K)*H(I,J)
        DELTAS = 0.5*(SMAX-SMINW)
        S1Z = 0.5*(SMAX+SMINW) - DELTAS*TANH((DEP-ZS)/DELTAZS)
        S(I,J,K) = S1Z 
      END DO
    ENDIF
  END DO
END DO
!
!Compute the Density from Wang
!
RHOAVER = 0.
IF (UNESCO) THEN
  CALL DENSUNESCO
ELSE
  CALL DENS
ENDIF
!
!  Compute SAVER,TAVER and RHOAVER.
!
VOLUME = 0.
MASS = 0.
SAVER = 0.
TAVER = 0.
DO I = 1,IM-1
  DO J = 1,JM-1
    IF (FSM(I,J).GT.0.) THEN
      VOLUME = VOLUME + H(I,J)
      DO K = 1,KB-1
        MASS = MASS + RHO(I,J,K)*H(I,J)*DZ(K)
        SAVER = SAVER + S(I,J,K)*H(I,J)*DZ(K)
        TAVER = TAVER + T(I,J,K)*H(I,J)*DZ(K)
      END DO
    ENDIF
  END DO
END DO
MASS = MASS/VOLUME
SAVER = SAVER/VOLUME
TAVER = TAVER/VOLUME
RHOAVER = MASS
WRITE(*,*)'MASS=',MASS,SAVER,TAVER
DO J = 1,JM
  DO I = 1,IM
      DO K = 1,KB-1
        RHO(I,J,K) =RHO(I,J,K)-MASS
      END DO
  END DO
END DO
!
!Initialize dynamic depths D, DU and DV.
!
CALL UPDATEDD
!
!   Zero the arrays in land points.
!
DO K = 1,KB-1
  DO J = 1,JM
    DO I = 1,IM
      RHO(I,J,K) = RHO(I,J,K)*FSM(I,J)
      S(I,J,K) = S(I,J,K)*FSM(I,J)
      T(I,J,K) = T(I,J,K)*FSM(I,J)
      U(I,J,K) = U(I,J,K)*DUM(I,J)
      V(I,J,K) = V(I,J,K)*DVM(I,J)
    END DO
  END DO
END DO
DO J = 1,JM
  DO I = 1,IM
    ETA(I,J) = ETA(I,J)*FSM(I,J)
  END DO
END DO
!
! Initiate KM, KH, KQ, Q2, Q2L, 
! SSURF, TSURF, WUBOT, WVBOT, WUSURF and WVSURF.
!
KM = 1.E-3
KH = 1.E-4
KQ = 1.E-4
Q2 = 1.E-4
Q2L = 1.E-4
KM(1:IM,1:JM,1) = 0.
KH(1:IM,1:JM,1) = 0.
KQ(1:IM,1:JM,1) = 0.
KM(1:IM,1:JM,KB) = 0.
KH(1:IM,1:JM,KB) = 0.
KQ(1:IM,1:JM,KB) = 0.
WUSURF = 0.0
WVSURF = 0.0
PATM = PMEAN
SSURF = 0.0
TSURF = 0.0
!
WUBOT = 0.
WVBOT = 0.
!
!2-D boundary value arrays.
!
ETAFRS = 0.
ETATFRS = 0.
ETABFRS = 0.
UAFRS = 0.
UATFRS = 0.
VAFRS = 0.
VATFRS = 0.
!
!3-D boundary value arrays.
!
UFRS = U
VFRS = V
UTFRS = 0.
VTFRS = 0.
SFRS = S
TFRS = T
Q2FRS = Q2
Q2LFRS = Q2L
!
!
!  Initialize ver 4.0 variables
!
UNM1 = U
DELUN = 0.
DELUSTAR = 0.
DELUNM1 = 0.
!
VNM1 = V
DELVN = 0.
DELVSTAR = 0.
DELVNM1 = 0.
!
SNM1 = S
DELSN = 0.
DELSSTAR = 0.
DELSNM1 = 0.
!
TNM1 = T
DELTN = 0.
DELTSTAR = 0.
DELTNM1 = 0.

TN = T
SN = S
UN = U
VN = V

RETURN
END SUBROUTINE FIELDINIT
