SUBROUTINE NCALFA
!***BEGIN PROLOGUE NCALFA
!
!          This routine was originally written by Harald
!          Engedal, The Norwegian Meteorological Institute,
!          Box 320, 0314 Oslo 3, NORWAY.
!
!          NCALFA is later revised by
!            Jarle Berntsen 
!          Latest revision 140799
!
!
! ******************************************************************
!
!-----------------------------------------------------------------------
!  COMPUTES THE RELAXATION PARAMETERS USED BY THE FLOW RELAXATION SCHEME IN THE
!  BOUNDARY ZONES.
!  HERE : *** ALFA-2 (HYPERBOLIC REPR.) ***
!-----------------------------------------------------------------------
!
!***END PROLOGUE NCALFA
!
!   Common variables
!
USE MOD_BOUND
IMPLICIT NONE
!
!   Local variables
!
INTEGER I,JJ
REAL X,IK
REAL DTE0,DTE,DTEETA
REAL KAPPA(LB)
!
!***********************************************************************
!**                  THE RELAXATION PARAMETER                         **
!***********************************************************************
!
!   COMPUTES THE RELAXATION FACTOR "ALFA" FOR ONE COLUMN IN THE
!   I (X) -DIRECTION AND FOR ONE COLUMN IN THE J (Y) -DIRECTION. THEN,
!   THESE VALUES ARE FILLED INTO THE REST OF THE ARRAY "ALFA".
!
DO I = 1,LB-1
  JJ=I-1
  X=TANH(0.5*JJ)
  ALPHA(I)=1.0-X
END DO
ALPHA(LB)=0.
ALPHAE(1)=1.0
ALPHAE(LB)=0.
!JB
!   We assume that these alfas are appropriate for DT = DTE0
!   and compute corresponding kappas.
!JB
!  Approx. DTE0 = DX/SQRT(2*G*DEPMAX)
!
DTE0 = 1.0
!
DO I = 2,LB-1
  KAPPA(I) = ALPHA(I)/(DTE0*(1.0-ALPHA(I)))
END DO
!JB
!   Then recompute the alfas for the actual value of DT
!   First ALPHA that is to be used for 3-D variables.
!JB
DO I = 2,LB-1
  ALPHA(I) = KAPPA(I)*DT/(1.+KAPPA(I)*DT)
END DO
!
!  Then ALPHAE to be used in 2-D external time steps.
!
DTE = DT/N2D
DO I = 2,LB-1
  ALPHAE(I) = KAPPA(I)*DTE/(1.+KAPPA(I)*DTE)
END DO
WRITE(*,*)'THE alphas'
DO I = 1,LB
  WRITE(*,*)I,ALPHA(I),ALPHAE(I)
END DO
!
RETURN
END
