SUBROUTINE VERTDIFF(F,WFSURF)
!
!  VERTDIFF propagates the solution of the equations
!
!  d(FD)/dt = d((KH/D)*d(F)/d(sigma))/d(sigma)
!
!  with boundary conditions:
!
!  (KH/D)*d(F)/d(sigma) = WFSURF  at sigma=0
!  (KH/D)*d(F)/d(sigma) = 0 at sigma=-1
!
!  The solutions are propagated with an fully implicit method.
!
USE STATE
IMPLICIT NONE
REAL F(IM,JM,KB),WFSURF(IM,JM)
!
! Local variables.
!
INTEGER I,J,K,pt
REAL DSQ
!REAL, DIMENSION(IM,JM,KB-1) :: ALF,BET
REAL, DIMENSION(kb-1) :: RHS,A,B,C,G, alf, bet
!
!
!  First propagate the F-equation over all internal sea points.
!

!$omp parallel do private( i,j,k, rhs,a,b,c,g,alf,bet, dsq) &
!$omp firstprivate(dt,dz,dzz)
DO pt=1,numcp
   i=indc(1,pt)
   j=indc(2,pt)
!DO J = 2,JM-1
!  DO I = 2,IM-1
!    IF (FSM(I,J).NE.0.) THEN
      DSQ = D(I,J)*D(I,J)
!
! Define the right hand side of the solution matrix.
!
      RHS(1) = F(I,J,1) + DT*WFSURF(I,J)/(D(I,J)*DZ(1))
      DO K = 2,KB-1
        RHS(K) = F(I,J,K)
      END DO
!
! Define the upper diagonal elements of the tridiagonal solution matrix.
!
      DO K = 1,KB-2
        B(K) = -DT*KH(I,J,K+1)/(DSQ*DZ(K)*DZZ(K))
      END DO
!
! Define the lower diagonal elements.
!
      DO K = 2,KB-1
        C(K) = -DT*KH(I,J,K)/(DSQ*DZ(K)*DZZ(K-1))
      END DO
!
! Define the diagonal elements.
!
      A(1) = 1. - B(1)
      DO K = 2,KB-2
        A(K) = 1. - B(K) - C(K)
      END DO
      A(KB-1) = 1. - C(KB-1)
!
! Solve the system of equations.
!
!
!   LU-decompose the linear system.
!
      ALF(1) = A(1)
      DO K = 2,KB-1
        ALF(K) = A(K) - C(K)*B(K-1)/ALF(K-1)
      END DO
      DO K = 2,KB-1
        BET(K) = C(K)/ALF(K-1)
      END DO
!
!   Forward substitute the right hand side.
!
      G(1) = RHS(1)
      DO K = 2,KB-1
        G(K) = RHS(K) - BET(K)*G(K-1)
      END DO
!
!   Back substitute to compute the solution F.
!
      F(i,j,KB-1) = G(KB-1)/ALF(KB-1)
      DO K = KB-2,1,-1
        F(i,j,K) = (G(K) - B(K)*F(i,j,K+1))/ALF(K)
      END DO
!    ENDIF
!  END DO
END DO
!
RETURN
END
